@@ -1,3 +1,3 @@
 from .app import App  # noqa
-from .base import BaseApp, app_registry  # noqa
+from .base import BaseApp, abstract_app_registry  # noqa
 from .mounted import MountedApp  # noqa
